def not_(a):
  """Checks if value is False. `📘`_

  - a: a boolean

  Example:
    >>> not_(False) == True
    >>> not_(True)  == False

  .. _📘:
    https://github.com/python3f/extra-boolean/wiki/not
  """
  return not a
